colour.quality.dataset.tcs Module — Colour 0.3.0 documentation

# colour.quality.dataset.tcs Module

## Test Colour Samples Spectral Power Distributions

Defines the CIE 1995 test colour samples spectral power distributions.

The CIE 1995 test colour samples data is in the form of a dict of `colour.colorimetry.spectrum.SpectralPowerDistribution` classes as follows:

    {'name': SpectralPowerDistribution, ..., 'name': SpectralPowerDistribution}

See also

Colour Rendering Index IPython Notebook

References

[1] | http://cie2.nist.gov/TC1-69/NIST%20CQS%20simulation%207.4.xls (Last accessed 10 June 2014)

[2] | http://onlinelibrary.wiley.com/store/10.1002/9781119975595.app7/asset/app7.pdf?v=1&t=hw7zl300&s=060f34ef1feb8bfa754b9c63c68bcc0808ac6730

`colour.quality.dataset.tcs.` `TCS_APPROXIMATE_MUNSELL_NOTATIONS` = CaseInsensitiveMapping({u'TCS14': u'5 GY 4/4', u'TCS10': u'5 Y 8/10', u'TCS11': u'4.5 G 5/8', u'TCS12': u'3 PB 3/11', u'TCS13': u'5 YR 8/4', u'TCS09': u'4.5 R 4/13', u'TCS08': u'10 P 6/8', u'TCS03': u'5 GY 6/8', u'TCS02': u'5 Y 6/4', u'TCS01': u'7.5 R 6/4', u'TCS07': u'2.5 P 6/8', u'TCS06': u'5 PB 6/8', u'TCS05': u'10 BG 6/4', u'TCS04': u'2.5 G 6/6'})

  Test colour samples Munsell colour approximations.

  TCS_APPROXIMATE_MUNSELL_NOTATIONS : dict

`colour.quality.dataset.tcs.` `TCS_SPDS` = {u'TCS14': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c07d0>, u'TCS10': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0810>, u'TCS11': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0850>, u'TCS12': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0890>, u'TCS13': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c08d0>, u'TCS09': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0910>, u'TCS08': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0950>, u'TCS03': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0990>, u'TCS02': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c09d0>, u'TCS01': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0a10>, u'TCS07': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0a50>, u'TCS06': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0a90>, u'TCS05': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0ad0>, u'TCS04': <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x1031c0b10>}

  Test colour samples spectral power distributions.

  TCS_SPDS : dict